==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gems/dialogs_es.lua <==

dialogId("zav-v-sto", "font_big", "Please note, that this level contains one hundred and nine objects.")
dialogStr("Toma nota, que este nivel contiene ciento nueve objetos.")


dialogId("zav-v-trpyt", "font_big", "And all of them gleam beautifully.")
dialogStr("Y todos ellos brillan de forma hermosa.")


dialogId("zav-m-pohnout", "font_small", "Please note, that I can`t move a fin here.")
dialogStr("Toma nota, que no puedo mover ni una aleta aquí.")


dialogId("zav-m-krasa", "font_small", "It`s beautiful! Everything gleams so much...")
dialogStr("¡Es hermoso! Todo el lugar resplandece...")


dialogId("zav-v-venku", "font_big", "It`ll be much nicer when we get out.")
dialogStr("Será mucho más hermoso cuando salgamos.")


dialogId("zav-v-zaval", "font_big", "This is very dangerous cave-in. We are lucky to be alive.")
dialogStr("Esta es una gruta muy peligrosa. Tenemos suerte de estar vivos.")


dialogId("zav-m-hopskok", "font_small", "Don`t speak too soon. We`re still in here.")
dialogStr("No te anticipes. Todavía estamos aquí.")


dialogId("zav-m-kameny", "font_small", "Don`t you think that these stones are arranged in a different way?")
dialogStr("¿No crees que esas piedras están organizadas de una forma distinta?")


dialogId("zav-v-zeleny", "font_big", "You are right. That green one was surely over there!")
dialogStr("Tienes razón. ¡Esa verde, seguro que estaba por allá!")


dialogId("zav-v-restart", "font_big", "I think that these jewels arrange themselves in a different way after each restart.")
dialogStr("Creo que esas joyas se ordenan a si mismas en una forma distinta después de reiniciar.")


dialogId("zav-m-pravda", "font_small", "Yeah, you`re right. Maybe they form some sensible pattern sometimes.")
dialogStr("Si, tienes razón. Quizás forman algún patron en especial algunas veces.")


dialogId("zav-m-hrac", "font_small", "Look, our player obviously satiated his need for colors.")
dialogStr("Mira, nuestro jugador obviamente sació su hambre de colores.")


dialogId("zav-v-zachranit", "font_big", "Maybe he could try to save us instead now.")
dialogStr("Quizás ahora intente grabarnos en esta ocasión.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/gems/dialogs_es.lua <==

dialogId("zav-v-sto", "font_big", "Please note, that this level contains one hundred and nine objects.")
dialogStr("Toma nota, que este nivel contiene ciento nueve objetos.")


dialogId("zav-v-trpyt", "font_big", "And all of them gleam beautifully.")
dialogStr("Y todos ellos brillan de forma hermosa.")


dialogId("zav-m-pohnout", "font_small", "Please note, that I can’t move a fin here.")
dialogStr("Toma nota, que no puedo mover ni una aleta aquí.")


dialogId("zav-m-krasa", "font_small", "It’s beautiful! Everything gleams so much...")
dialogStr("¡Es hermoso! Todo el lugar resplandece...")


dialogId("zav-v-venku", "font_big", "It’ll be much nicer when we get out.")
dialogStr("Será mucho más hermoso cuando salgamos.")


dialogId("zav-v-zaval", "font_big", "This is very dangerous cave-in. We are lucky to be alive.")
dialogStr("Esta es una gruta muy peligrosa. Tenemos suerte de estar vivos.")


dialogId("zav-m-hopskok", "font_small", "Don’t speak too soon. We’re still in here.")
dialogStr("No te anticipes. Todavía estamos aquí.")


dialogId("zav-m-kameny", "font_small", "Don’t you think that these stones are arranged in a different way?")
dialogStr("¿No crees que esas piedras están organizadas de una forma distinta?")


dialogId("zav-v-zeleny", "font_big", "You are right. That green one was surely over there!")
dialogStr("Tienes razón. ¡Esa verde, seguro que estaba por allá!")


dialogId("zav-v-restart", "font_big", "I think that these jewels arrange themselves in a different way after each restart.")
dialogStr("Creo que esas joyas se ordenan a si mismas en una forma distinta después de reiniciar.")


dialogId("zav-m-pravda", "font_small", "Yeah, you’re right. Maybe they form some sensible pattern sometimes.")
dialogStr("Si, tienes razón. Quizás forman algún patron en especial algunas veces.")


dialogId("zav-m-hrac", "font_small", "Look, our player obviously satiated his need for colors.")
dialogStr("Mira, nuestro jugador obviamente sació su hambre de colores.")


dialogId("zav-v-zachranit", "font_big", "Maybe he could try to save us instead now.")
dialogStr("Quizás ahora intente grabarnos en esta ocasión.")
